@@ -423,13 +423,12 @@ void  CodeEditor::contextMenuEvent(QContextMenuEvent *event) {
      QTextCursor cursor = cursorForPosition( event->pos());
      QTextBlock block=cursor.block();
      QString aname=block.text().section(" ",0,0);
-     QStringList bfl=shxToolTips.filter(QRegExp(QString("^%1").arg(aname)));
+     QStringList bfl=shxToolTips.filter(QRegExp(QString("^%1\\b").arg(aname)));
      if (bfl.isEmpty()){
         QString data=block.text().remove("=").trimmed();                                      // findInStructure
         a=menu->addAction(QString("locate %1 in structure").arg(aname) ,this,SLOT(searchInStructure()));
         a->setData(data);
-
-    }
+     }//else {qDebug()<<bfl;}
 
      if (textCursor().hasSelection()){
          a=menu->addAction(QString("select atoms in structure found in selected text"),
