@@ -690,13 +690,17 @@ void EacDlg::exportSettings(){
   eaSettings->setValue("BondColor",mol->bondColor);
   eaSettings->setValue("BondStyle",mol->bondColorStyle);
   eaSettings->setValue("BondStrength",mol->bondStrength);
+
+  eaSettings->setValue("HBondMaxDist",mol->hbdist());
+  eaSettings->value("HBondMaxAng",mol->hbangl());
   eaSettings->endGroup();
   delete eaSettings;
   //--------------------------------------
   //
 }
 
-void EacDlg::kradChanged(double d){eacGLW->mol->Kovalenz_Radien[psew->selection]=mol->Kovalenz_Radien[psew->selection]=(int)(d*100);
+void EacDlg::kradChanged(double d){
+  eacGLW->mol->Kovalenz_Radien[psew->selection]=mol->Kovalenz_Radien[psew->selection]=(int)(d*100);
   mol->einstellung->beginGroup("Atoms");
   mol->einstellung->beginWriteArray("CovaleceRadii",95);
   for (int i = 0; i < 95; ++i) {
@@ -709,6 +713,28 @@ void EacDlg::kradChanged(double d){eacGLW->mol->Kovalenz_Radien[psew->selection]
   update();
 }
 
+
+void EacDlg::hbdistChanged(double){
+    mol->einstellung->beginGroup("Bonds");
+    mol->setHBondMaxDist(eacHBDist->value());
+    mol->einstellung->setValue("HBondMaxDist",eacHBDist->value());
+    mol->setHBondMaxAngl(eacHBAngl->value());
+    mol->einstellung->setValue("HBondMaxAng",eacHBAngl->value());
+    mol->einstellung->endGroup();
+    mol->einstellung->sync();
+    update();
+}
+
+void EacDlg::hbanglChanged(double){
+    mol->einstellung->beginGroup("Bonds");
+    mol->setHBondMaxDist(eacHBDist->value());
+    mol->einstellung->setValue("HBondMaxDist",eacHBDist->value());
+    mol->setHBondMaxAngl(eacHBAngl->value());
+    mol->einstellung->setValue("HBondMaxAng",eacHBAngl->value());
+    mol->einstellung->endGroup();
+    mol->einstellung->sync();
+    update();
+}
 void EacDlg::radChanged(double d){
 
   eacGLW->mol->arad[psew->selection] = mol->arad[psew->selection] = d;
@@ -742,6 +768,8 @@ EacDlg::EacDlg(Molecule *externMole){
   //eacCB = new QComboBox;
   eacRAD = new QDoubleSpinBox();
   eacKRAD = new QDoubleSpinBox();
+  eacHBDist = new QDoubleSpinBox();
+  eacHBAngl = new QDoubleSpinBox();
   //QLabel *smbl =new QLabel("Element symbol");
   QLabel *rad =new QLabel("Sphere radius");
   QLabel *krad =new QLabel("Covalent radius");
@@ -802,6 +830,8 @@ EacDlg::EacDlg(Molecule *externMole){
   glt->addWidget(singleC);
   glt->addWidget(colorbut2);
   QHBoxLayout *glt2= new QHBoxLayout();
+  QHBoxLayout *glt5= new QHBoxLayout();
+  QHBoxLayout *glt6= new QHBoxLayout();
   glt2->addWidget(bondStrength);
   QLabel *bsl = new QLabel("Bond strength");
   QLabel *lodl = new QLabel("Level of detail");
@@ -815,7 +845,12 @@ EacDlg::EacDlg(Molecule *externMole){
   QHBoxLayout *glt3= new QHBoxLayout();
   glt3->addWidget(lodSpinBox);
   glt3->addWidget(lodl);
-
+  glt6->addWidget(eacHBDist);
+  QLabel *hbdl = new QLabel("Max H-Acceptor Distance");
+  glt6->addWidget(hbdl);
+  QLabel *hbal = new QLabel("Min H-Bond Angle");
+  glt5->addWidget(eacHBAngl);
+  glt5->addWidget(hbal);
   QDoubleSpinBox* qPeakSizeSBx = new QDoubleSpinBox();
   qPeakSizeSBx->setValue(mol->qPeakRad);
   qPeakSizeSBx->setDecimals(3);
@@ -831,6 +866,8 @@ EacDlg::EacDlg(Molecule *externMole){
   glt->addLayout(glt2);
   glt->addLayout(glt3);
   glt->addLayout(glt4);
+  glt->addLayout(glt6);
+  glt->addLayout(glt5);
   globalStuff->setLayout(glt);
   walbx = new QCheckBox("Draw intersecting planes");
   walbx->setTristate();
@@ -886,6 +923,18 @@ EacDlg::EacDlg(Molecule *externMole){
   eacRAD->setSingleStep(0.01);
   connect(eacKRAD,SIGNAL(valueChanged(double)),this,SLOT(kradChanged(double)) );
   connect(eacRAD,SIGNAL(valueChanged(double)),this,SLOT(radChanged(double)) );
+  eacHBDist->setValue(eacGLW->mol->hbdist());
+  eacHBDist->setDecimals(2);
+  eacHBDist->setSingleStep(0.01);
+
+  eacHBAngl->setMaximum(180.0);
+  eacHBAngl->setMinimum(0.0);
+  eacHBAngl->setValue(eacGLW->mol->hbangl());
+  eacHBAngl->setDecimals(1);
+  eacHBAngl->setSingleStep(0.1);
+
+  connect(eacHBDist,SIGNAL(valueChanged(double)),this,SLOT(hbdistChanged(double)) );
+  connect(eacHBAngl,SIGNAL(valueChanged(double)),this,SLOT(hbanglChanged(double)) );
   eacGLO->addWidget(eacGLW,0,0,6,6);
   eacGLO->addWidget(globalStuff,0,6,1,3);
   //eacGLO->addWidget(smbl,1,7);
