@@ -111,6 +111,8 @@ Q_OBJECT
   void radChanged(double d);//!< the ball radius used in ball stick mode is changed to d.
   void exportSettings();//!< export settings to a specified ini file.
   void importSettings();//!< import settings from a specified ini file.
+  void hbdistChanged(double);//!< maximal length for H-bonds
+  void hbanglChanged(double);//!< maximal angle for H-bonds
   protected slots:
   void accept () ;
   void reject () ;
@@ -126,6 +128,8 @@ Q_OBJECT
   //QComboBox *eacCB;
   QDoubleSpinBox *eacRAD;
   QDoubleSpinBox *eacKRAD;
+  QDoubleSpinBox *eacHBDist;
+  QDoubleSpinBox *eacHBAngl;
   QCheckBox *walbx;
   QCheckBox *rinbx;
   QCheckBox *sphbx;
