@@ -19,6 +19,7 @@
 #include "fourxle.h"
 #include <QtCore>
 #include <QtGui>
+//üäöß
 FourXle::FourXle(Molecule *mole_, ChGL *chgl_,QToolBar *toolView, double resol, double wght){
   mole =mole_;
   n1=n2=n3=n4=n5=0;
@@ -110,21 +111,36 @@ bool FourXle::loadFouAndPerform(const char filename[],bool neu){
   }
   f=fopen(filename,"rb");
   if (f==NULL)return false;
-  char line[122]="",*dum;
+  char line[122]="";
   while (strstr(line,"_refln_phase_calc")==NULL) {
-    dum=fgets(line,120,f);
+    fgets(line,120,f);
   }
   nr=0;
-
+  lr[nr].ih=0;
+  lr[nr].ik=0;
+  lr[nr].il=0; 
+  lr[nr].fo=f000*f000;
+  lr[nr].so=0.5f;
+  lr[nr].fc=f000;
+  lr[nr].phi=0.0f;
+  nr=1;
+//  printf("f000 %g\n",f000);
   emit bigmessage(QString::fromLocal8Bit(filename));
+
   while (!feof(f)){
-    dum=fgets(line,120,f);
+    fgets(line,120,f);
     int rdi=
     sscanf(line,"%d %d %d %f %f %f %f",&lr[nr].ih,&lr[nr].ik, &lr[nr].il ,&lr[nr].fo, &lr[nr].so, &lr[nr].fc, &lr[nr].phi);
-    if (rdi==7) {if ((abs(lr[nr].ih)<HKLMX)&&
+    if (rdi==7) {
+      if ((abs(lr[nr].ih)<HKLMX)&&
 		    (abs(lr[nr].ik)<HKLMX)&&
 		    (abs(lr[nr].il)<HKLMX)&&
-		    ((lr[nr].ih|lr[nr].ik|lr[nr].il)!=0)) nr++;}
+		    ((lr[nr].ih|lr[nr].ik|lr[nr].il)!=0))
+      
+        //printf("%4d%4d%4d %g %g\n", lr[nr].ih, lr[nr].ik, lr[nr].il ,lr[nr].fo, lr[nr].so);
+       nr++;
+    }
+
    // else printf("?? %d {%s}\n",rdi,line);
 
     if (nr>=LM) {
@@ -133,7 +149,7 @@ bool FourXle::loadFouAndPerform(const char filename[],bool neu){
     }
   }
   fclose(f);
-  if (!nr) {
+  if (nr<2) {
       emit bigmessage(QString("<font color=red>Map generation failed. No reflection data in file %1.</font>").arg(QString::fromLocal8Bit(filename)));
       return false;
   }
@@ -193,6 +209,7 @@ bool FourXle::loadFouAndPerform(const char filename[],bool neu){
   }
   n++;
   nr=n;
+//  printf("%4d%4d%4d %g %g %g %g\n",lr[0].ih,lr[0].ik,lr[0].il,lr[0].fo,lr[0].so,lr[0].fc,lr[0].phi);
   {
     float DX;
     float DY;
@@ -230,13 +247,17 @@ bool FourXle::loadFouAndPerform(const char filename[],bool neu){
     for (int typ=0; typ<2;typ++){
       double miZ=99999.99,maZ=-99999.99;
 //      mInimum[typ]=99999.99; mAximum[typ]=-99999.99;
-      //B=(fftwf_complex*)fftwf_malloc(sizeof(fftwf_complex)*n5);
       int nbytes,dims[3];
       dims[0]=n3;
       dims[1]=n2;
       dims[2]=n1;
+#ifdef FFTW3_H
+      B=(fftwf_complex*)fftwf_malloc(sizeof(fftwf_complex)*n5);
+      for (int i=0; i<n5; i++){B[i][0]=0;B[i][1]=0;}
+#else
       B=(kiss_fft_cpx*)KISS_FFT_MALLOC(nbytes = (sizeof(kiss_fft_cpx)*n5));
       for (int i=0; i<n5; i++){B[i].r=0;B[i].i=0;}
+#endif
       for (int i=0; i<nr;i++){
 	float  u,v,w;
 	u=lr[i].ih;
@@ -267,9 +288,14 @@ bool FourXle::loadFouAndPerform(const char filename[],bool neu){
 	  l=(999*n3+l)%n3;
 	  m=j+n1*(k+n2*l);
 	  p=ss*cosf(q);
-	  B[m].r=p;
 	  q=ss*sinf(q);
+#ifdef FFTW3_H
+	  B[m][0]=p;
+	  B[m][1]=q;
+#else
+	  B[m].r=p;
 	  B[m].i=q;
+#endif
 	  j*=-1;
 	  if(j<0)j=n1+j;
 	  k*=-1;
@@ -277,28 +303,45 @@ bool FourXle::loadFouAndPerform(const char filename[],bool neu){
 	  l*=-1;
 	  if(l<0)l=n3+l;
 	  m=j+n1*(k+n2*l);
+#ifdef FFTW3_H
+	  B[m][0]=p;
+	  B[m][1]=-q;
+#else
 	  B[m].r=p;
 	  B[m].i=-q;
+#endif
 	}
       }
+#ifdef FFTW3_H
+      fwd_plan = fftwf_plan_dft_3d(n3,n2,n1,B,B,FFTW_FORWARD,FFTW_ESTIMATE);
+      fftwf_execute(fwd_plan);
+      fftwf_destroy_plan(fwd_plan);
+#else
       fwd_plan = kiss_fftnd_alloc(dims,3,0,0,0);
-//      fwd_plan = fftwf_plan_dft_3d(n3,n2,n1,B,B,FFTW_FORWARD,FFTW_ESTIMATE);
-//      fftwf_execute(fwd_plan);
       kiss_fftnd( fwd_plan,B,B);
-//      fftwf_destroy_plan(fwd_plan);
       free(fwd_plan);
+#endif
       float t=0;
       double DM=0.,  DS=0., DD  ;
       for (int i=0; i<n5;i++){
+#ifdef FFTW3_H
+	DD=B[i][0];
+#else
 	DD=B[i].r;
+#endif
 //	maxi[typ]=fmax(maxi[typ],DD); mini[typ]=fmin(mini[typ],DD);
 	miZ=fmin(miZ,DD);
 	maZ=fmax(maZ,DD);
 	DM+=DD;
 	DS+=DD*DD;
+#ifdef FFTW3_H
+        if (typ==1) datfo[i]=B[i][0];
+        else if (typ==0) datfo_fc[i]=B[i][0];
+#else
         if (typ==1) datfo[i]=B[i].r;
         else if (typ==0) datfo_fc[i]=B[i].r;
 
+#endif
       }
       sigma[typ]=t=sqrt((DS/n5)-((DM/n5)*(DM/n5)));
 
@@ -444,7 +487,9 @@ int FourXle::readHeader(const char *filename){
       sscanf(line,"_shelx_title %[^\r\n]",titl);
       trimm(titl);
     }
-
+    if (!strncmp(dum,"_exptl_crystal_F_000",20)){
+        sscanf(line,"_exptl_crystal_F_000 %f",&f000);
+    }
     if (!strncmp(dum,"_shelx_refln_list_code",22)) {
         sscanf(line,"_shelx_refln_list_code %d",&listcode);
         //qDebug()<<listcode;
@@ -1206,6 +1251,192 @@ V3 FourXle::CalcNormalZ( int ix, int iy, int iz ) {
   return Normalize((tang[0] - tang[1])%(tang[2] - tang[3]));
 }
 
+void FourXle::jnk(){
+  if(!n5)return;
+  float mini=9e37,maxi=-9e37;
+  float f,r,fstep;
+  double DM,DS,sigma,w,e_net,e_gross;
+  r=powf((3*(n1-1)*(n2-1)*(n3-1)),1.0f/3.0f);
+//  printf("%d %d %d %d %f\n",n1,n2,n3,n5,r);
+  float *datfo_fcstp=(float*) malloc(sizeof(float)*n5);
+  float invstep=100.0f;
+  float step=1.0f/invstep;
+  float rhomind2=99999.0f,rhomaxd2=-99999.0f;
+  QMap<float,int> hash;
+  QMap<float,float> hashf;
+  DM=0.0f;
+  DS=0.0f;
+  w=0.0f;
+  for (int i=0; i<n5; i++){
+      f=datfo_fc[i];
+      mini=qMin(f,mini);
+      maxi=qMax(f,maxi);
+      DM+=f;
+      DS+=f*f;
+      w+=fabs(f);
+      datfo_fcstp[i]=floorf(f*invstep);
+  }// */
+  e_net=(DM/n5)*C[14];//C[14] ist das Volumen der UC
+  e_gross=w/(2*n5)*C[14];
+  sigma=sqrt((DS/n5)-((DM/n5)*(DM/n5)));
+  //printf("%g %g %g",e_net,e_gross,sigma);
+  for (int zi=0;zi<n3;zi++)
+    for (int yi=0;yi<n2;yi++)
+      for (int xi=0;xi<(n1-1);xi++){
+        if (datfo_fcstp[dex(xi,yi,zi)]>datfo_fcstp[dex(xi+1,yi,zi)]){
+          fstep=datfo_fcstp[dex(xi,yi,zi)];
+          int ze=fstep-datfo_fcstp[dex(xi+1,yi,zi)];
+          for (int zii=0; zii<ze; zii++) hash[(fstep-zii)*step]++;
+        }else if (datfo_fcstp[dex(xi,yi,zi)]<datfo_fcstp[dex(xi+1,yi,zi)]){
+          fstep=datfo_fcstp[dex(xi+1,yi,zi)];
+          int ze=fstep-datfo_fcstp[dex(xi,yi,zi)];
+          for (int zii=0; zii<ze; zii++) hash[(fstep-zii)*step]++;
+        }
+      }
+  for (int xi=0;xi<n1;xi++)
+    for (int zi=0;zi<n3;zi++)
+      for (int yi=0;yi<(n2-1);yi++){
+        if (datfo_fcstp[dex(xi,yi,zi)]>datfo_fcstp[dex(xi,yi+1,zi)]){
+          fstep=datfo_fcstp[dex(xi,yi,zi)];
+          int ze=fstep-datfo_fcstp[dex(xi,yi+1,zi)];
+          for (int zii=0; zii<ze; zii++) hash[(fstep-zii)*step]++;
+        }else if (datfo_fcstp[dex(xi,yi,zi)]<datfo_fcstp[dex(xi,yi+1,zi)]){
+          fstep=datfo_fcstp[dex(xi,yi+1,zi)];
+          int ze=fstep-datfo_fcstp[dex(xi,yi,zi)];
+          for (int zii=0; zii<ze; zii++) hash[(fstep-zii)*step]++;
+        }
+      }
+
+  for (int yi=0;yi<n2;yi++)
+    for (int xi=0;xi<n1;xi++)
+      for (int zi=0;zi<(n3-1);zi++){
+        if (datfo_fcstp[dex(xi,yi,zi)]>datfo_fcstp[dex(xi,yi,zi+1)]){
+          fstep=datfo_fcstp[dex(xi,yi,zi)];
+          int ze=fstep-datfo_fcstp[dex(xi,yi,zi+1)];
+          for (int zii=0; zii<ze; zii++) hash[(fstep-zii)*step]++;
+        }else if (datfo_fcstp[dex(xi,yi,zi)]<datfo_fcstp[dex(xi,yi,zi+1)]){
+          fstep=datfo_fcstp[dex(xi,yi,zi+1)];
+          int ze=fstep-datfo_fcstp[dex(xi,yi,zi)];
+          for (int zii=0; zii<ze; zii++) hash[(fstep-zii)*step]++;
+        }
+      }
+  free(datfo_fcstp);
+  //float range=fmaxf(fabsf(mini),fabsf(maxi));
+  QDialog *jnkdlg = new QDialog();
+   QGraphicsScene*scene= new QGraphicsScene(-30,-50,550,586);
+  scene->setBackgroundBrush(QBrush(QColor("#e9f7d6")));
+  scene->clear ();
+  QGraphicsItem *itm;
+  for (int i=0; i<21;i++){
+    itm=scene->addLine(i*25,0,i*25,500,(i%5)?QPen(QColor("#cbdbbb"),0):QPen(QColor("#959d9d"),0));
+    itm->setData(0,-1);
+  }
+  for (int i=0; i<31;i++){
+  itm=scene->addLine(0,i*16.66666666666667,500,i*16.66666666666667,(i%5)?QPen(QColor("#cbdbbb"),0):QPen(QColor("#959d9d"),0));
+  itm->setData(0,-1);
+  }
+  itm=scene->addLine(250,0,250,500,QPen(QColor("#000000"),0));
+  itm=scene->addLine(0,83.33333333333333,500,83.33333333333333,QPen(QColor("#000000"),0));
+  itm=scene->addLine(0,250,500,250,QPen(QColor("#000000"),0));
+  itm=scene->addLine(0,416.6666666666667,500,416.6666666666667,QPen(QColor("#000000"),0));
+  QGraphicsTextItem *txt = scene->addText("3");
+  txt->moveBy(-15,73.33333333333333);
+  txt = scene->addText("2");
+  txt->moveBy(-15,240);
+  txt = scene->addText("1");
+  txt->moveBy(-15,406.6666666666667);
+  txt = scene->addText("-1.0");
+  txt->moveBy(-15,500);
+  txt = scene->addText("0");
+  txt->moveBy(241,500);
+  txt = scene->addText("1.0");
+  txt->moveBy(485,500);
+
+
+  QMapIterator<float, int> i(hash);
+  while (i.hasNext()) {
+    i.next();
+    f=hashf[i.key()]=logf(i.value())/logf(r);
+    scene->addEllipse(250+(i.key())*250,500-((f-0.5)/3.)*500,4,4,QPen(Qt::NoPen),QBrush(QColor("#0907e6")));
+
+    if (f>2){
+        rhomind2=qMin(rhomind2,i.key());
+        rhomaxd2=qMax(rhomaxd2,i.key());
+    }
+   // printf("jnk: %g %g %g %g %g %g\n",i.key(),f,rhomind2,rhomaxd2,250+(i.key())*250,500-((f-0.5)/3.)*500);
+  }
+ // printf("\ndf(0)= %g %d %g %g\n",hashf.value(0.0f),hash.value(0.0f),rhomind2,rhomaxd2);
+
+  float m,b;
+  m=(hashf.value(rhomind2)-hashf.value(rhomind2-step))/step;
+  b=hashf.value(rhomind2)-m*rhomind2;
+  rhomind2=(2.0f-b)/m;
+  m=(hashf.value(rhomaxd2)-hashf.value(rhomaxd2-step))/step;
+  b=hashf.value(rhomaxd2)-m*(rhomaxd2);
+  rhomaxd2=(2.0f-b)/m;
+ // printf("df(0)= %g %d %g %g\n",hashf.value(0.0f),hash.value(0.0f),rhomind2,rhomaxd2);
+  txt = scene->addText(QString("df(0) = %1").arg((double)hashf.value(0.0f),7,'f',2),QFont("Courier",10));
+  txt->moveBy(328,2);
+  txt = scene->addText(QString("min(d=2) = %1 eA^-3").arg((double)rhomind2,7,'f',3),QFont("Courier",10));
+  txt->moveBy(305,18);
+  txt = scene->addText(QString("max(d=2) = %1 eA^-3").arg((double)rhomaxd2,7,'f',3),QFont("Courier",10));
+  txt->moveBy(305,34);
+  txt = scene->addText(QString("min      = %1 eA^-3").arg((double)mini,7,'f',3),QFont("Courier",10));
+  txt->moveBy(305,50);
+  txt = scene->addText(QString("max      = %1 eA^-3").arg((double)maxi,7,'f',3),QFont("Courier",10));
+  txt->moveBy(305,66);
+  txt = scene->addText(QString("e_net    = %1 e").arg((double)e_net,8,'g',3),QFont("Courier",10));
+  txt->moveBy(295,82);
+  txt = scene->addText(QString("e_gross  = %1 e").arg((double)e_gross,8,'g',3),QFont("Courier",10));
+  txt->moveBy(295,98);
+  txt = scene->addText(QString("         = %1 eA^-3").arg((double)sigma,8,'f',3),QFont("Courier",10));
+  txt->moveBy(295,116);
+  txt = scene->addText(QString("nx ny nz  %1 x %2 x %3 = %4").arg(n1).arg(n2).arg(n3).arg(n5),QFont("Courier",9));
+  txt->moveBy(30,2);
+  txt = scene->addText(QString("fractal dimension vs. residual density"),QFont("Helvetica",14,QFont::Bold));
+  txt->moveBy(100,-40);
+  txt = scene->addText(QString("df"),QFont("Helvetica",12,QFont::Bold));
+  txt->moveBy(-20,20);
+  txt = scene->addText(QString("0"),QFont("Helvetica",12,QFont::Bold));
+  txt->moveBy(460,500);
+
+  #ifdef __APPLE__
+    txt = scene->addText(QString::fromUtf8("𝛒"),QFont("Helvetica",16,QFont::Bold));
+    txt->moveBy(450,490);
+    txt = scene->addText(QString::fromUtf8("𝛒"),QFont("Helvetica",14));
+    txt->moveBy(295,8);
+    txt = scene->addText(QString::fromUtf8("𝛒"),QFont("Helvetica",14));
+    txt->moveBy(295,24);
+    txt = scene->addText(QString::fromUtf8("𝛒"),QFont("Helvetica",14));
+    txt->moveBy(295,40);
+    txt = scene->addText(QString::fromUtf8("𝛒"),QFont("Helvetica",14));
+    txt->moveBy(295,56);
+    txt = scene->addText(QString::fromUtf8("𝛔"),QFont("Helvetica",14));
+    txt->moveBy(295,106);
+  #else
+  txt = scene->addText(QString::fromUtf8("ρ"),QFont("Helvetica",16,QFont::Bold));
+  txt->moveBy(450,490);
+  txt = scene->addText(QString::fromUtf8("ρ"),QFont("Helvetica",14));
+  txt->moveBy(295,8);
+  txt = scene->addText(QString::fromUtf8("ϱ"),QFont("Helvetica",14));
+  txt->moveBy(295,24);
+  txt = scene->addText(QString::fromUtf8("ϱ"),QFont("Helvetica",14));
+  txt->moveBy(295,40);
+  txt = scene->addText(QString::fromUtf8("ϱ"),QFont("Helvetica",14));
+  txt->moveBy(295,56);
+  txt = scene->addText(QString::fromUtf8("σ"),QFont("Helvetica",14));
+  txt->moveBy(295,106);
+  #endif  // */
+  txt = scene->addText(QString("Please cite as: 'K. Meindl, J. Henn, Acta Cryst., 2008, A64, 404-418.'"),QFont("Helvetica",9));
+  txt->moveBy(100,516);
+  QGraphicsView *view = new QGraphicsView(scene,jnkdlg);
+
+  QVBoxLayout *lt = new QVBoxLayout(jnkdlg);
+  lt->addWidget(view);
+  jnkdlg->show();
+
+
+}
 
 inline int FourXle::dex(int x,int y, int z){
   /*! dex is used to adress elemennts of a one dimensional array by three indizes like it is a 3 dimensional array
