@@ -76,6 +76,7 @@ Q_OBJECT
           int HKLMX;//!< Maximum of h,k and l values can be used to make a resulution cut. 
           float *datfo,//!<data pointer for the fobs map in real space
 		*datfo_fc;//!<data pointer for the fobs-fcalc map in real space
+          float f000;
           FourXle(Molecule *mole_, ChGL *chgl_,QToolBar *toolView, double resol=2.5, double wght=1.1);
 	  /*!< @param mole_ pointer to the Molecule of ShelXle 
 	   *  @param chgl_ pointer to the ChGL widged of ShelXle
@@ -107,6 +108,7 @@ Q_OBJECT
           ChGL *chgl;//!< pointer to the ChGL widget
 	  void deleteLists();
 	  void killmaps();
+          void jnk();
 	  int n1,//!< dimension of the map in a diRection
 	      n2,//!< dimension of the map in b diRection
 	      n3,//!< dimension of the map in c diRection
