@@ -259,6 +259,7 @@ void HistoryWidget::setPath(QString dirName,int wid){
 
     // vers++;
   }
+  FreeWerte.clear();
   RWerte.clear();
   RallWerte.clear();
   gooddata.clear();
@@ -273,6 +274,7 @@ void HistoryWidget::setPath(QString dirName,int wid){
     alt.close();
     inhalt = inhalt.section("\nHKLF ",1);
 
+
     //REM R1 =  0.0150 for   6927 Fo > 4sig(Fo)  and  0.0160 for all   7220 data
     QStringList sl = inhalt.section("REM R1 =",1).section("\n",0,0).trimmed().split(" ",QString::SkipEmptyParts);
     if (sl.size()<11) continue;
@@ -280,11 +282,17 @@ void HistoryWidget::setPath(QString dirName,int wid){
     gooddata.append(sl.at(2).toInt());
     RallWerte.append(sl.at(7).toDouble()*100.0);
     alldata.append(sl.at(10).toInt());
+    //R1(Free) =
+    QStringList slfree = inhalt.section("REM R1(Free) =",1).section("\n",0,0).trimmed().split(" ",QString::SkipEmptyParts);
+    if (slfree.size()>1){
+        FreeWerte[RWerte.size()-1]=slfree.at(0).toDouble()*100;
+    }
     sl = inhalt.section("REM R1 =",1).section("\n",1,1).trimmed().split(" ",QString::SkipEmptyParts);
     if (sl.size()<2) continue;
     parameters.append(sl.at(1).toInt());
     saveFilesList.append(alt.fileName());
     dateTimesList.append(QFileInfo(alt.fileName()).lastModified());
+
   }
 
   {
@@ -302,6 +310,13 @@ void HistoryWidget::setPath(QString dirName,int wid){
       gooddata.append(sl.at(2).toInt());
       RallWerte.append(sl.at(7).toDouble()*100.0);
       alldata.append(sl.at(10).toInt());
+      //R1(Free) =
+      QStringList slfree = inhalt.section("REM R1(Free) =",1).section("\n",0,0).trimmed().split(" ",QString::SkipEmptyParts);
+      if (slfree.size()>1){
+      FreeWerte[RWerte.size()-1]=slfree.at(0).toDouble()*100;
+      }
+
+
       sl = inhalt.section("REM R1 =",1).section("\n",1,1).trimmed().split(" ",QString::SkipEmptyParts);
       if (sl.size()<2) return;
       parameters.append(sl.at(1).toInt());
@@ -316,13 +331,20 @@ void HistoryWidget::setPath(QString dirName,int wid){
 
         inhalt = inhalt.section("\nHKLF ",1);
 	//REM R1 =  0.0150 for   6927 Fo > 4sig(Fo)  and  0.0160 for all   7220 data
-	QStringList sl = inhalt.section("REM R1 =",1).section("\n",0,0).trimmed().split(" ",QString::SkipEmptyParts);
+
+    QStringList sl = inhalt.section("REM R1 =",1).section("\n",0,0).trimmed().split(" ",QString::SkipEmptyParts);
 	if (sl.size()<11) return;
 	RWerte.append(sl.at(0).toDouble()*100.0);
 	gooddata.append(sl.at(2).toInt());
 	RallWerte.append(sl.at(7).toDouble()*100.0);
         alldata.append(sl.at(10).toInt());
-	sl = inhalt.section("REM R1 =",1).section("\n",1,1).trimmed().split(" ",QString::SkipEmptyParts);
+        //R1(Free) =
+        QStringList slfree = inhalt.section("REM R1(Free) =",1).section("\n",0,0).trimmed().split(" ",QString::SkipEmptyParts);
+        if (slfree.size()>1){
+        FreeWerte[RWerte.size()-1]=slfree.at(0).toDouble()*100;
+        }
+
+        sl = inhalt.section("REM R1 =",1).section("\n",1,1).trimmed().split(" ",QString::SkipEmptyParts);
 	if (sl.size()<2) return;
 	parameters.append(sl.at(1).toInt());
 	saveFilesList.append(alt.fileName());
@@ -358,15 +380,16 @@ QColor HistoryWidget::farbverlauf(double wrt){
 }
 
 void HistoryWidget::paintEvent(QPaintEvent *event){
-
   double x =0;
   for (int i=0; i<RWerte.size(); i++){
     x = qMax(RWerte.at(i),x);
+    if (FreeWerte.contains(i))
+        x = qMax(FreeWerte.value(i),x);
   }
   QPainter p(this);
-  setMinimumWidth(qMax(p.fontMetrics().width(QString("%1").arg(x,4,'f',2))*RWerte.size(),maxwid));
-  setMaximumWidth(qMax(p.fontMetrics().width(QString("%1").arg(x,4,'f',2))*RWerte.size(),maxwid));
-  p.fillRect(0,0,width(),height(),QPalette().window());// QColor("#eeeecc"));
+  setMinimumWidth(qMax(p.fontMetrics().width(QString("%1").arg(x,4,'f',3))*RWerte.size(),maxwid));
+  setMaximumWidth(qMax(p.fontMetrics().width(QString("%1").arg(x,4,'f',3))*RWerte.size(),maxwid));
+  p.fillRect(0,0,width(),height(),QPalette().window());// );QColor("#eeeecc")
   p.setPen(Qt::black);
 
   if  (RWerte.isEmpty()) return;
@@ -388,8 +411,19 @@ void HistoryWidget::paintEvent(QPaintEvent *event){
     p.drawText(i*w-((W-w+2)),0,W, fh,Qt::AlignCenter,QString("open save"));
     p.drawText(i*w-((W-w+2)),fh+2,W, fh,Qt::AlignCenter,QString("history"));
     }*/
+      if (FreeWerte.contains(i)){
+      p.setBrush(QBrush(farbverlauf(FreeWerte.value(i)*3)));
+      p.drawRect(i*w+5,qMax((int)(h-(FreeWerte.value(i)/25*h))-1,0),w*0.95-5,qMin((int)(FreeWerte.value(i)/25*h),h-2));
+    }
     p.setBrush(QBrush(farbverlauf(RWerte.at(i)*3)));
-    p.drawRect(i*w,qMax((int)(h-(RWerte.at(i)/25*h))-1,0),w-2,qMin((int)(RWerte.at(i)/25*h),h-2));
+    p.drawRect(i*w,qMax((int)(h-(RWerte.at(i)/25*h))-1,0),w*0.9,qMin((int)(RWerte.at(i)/25*h),h-2));
+      if (FreeWerte.contains(i)){
+          p.drawText(i*w, qMax((int)(h-(FreeWerte.value(i)/25*h)),fh+5)-fh-2, w,fh,Qt::AlignLeft, QString("%1")
+                  .arg(RWerte.at(i),4,'f',2));
+
+          p.drawText(i*w, qMax((int)(h-((FreeWerte.value(i))/25*h))-fh,fh+5)-fh-2, w,fh,Qt::AlignLeft, QString("%1")
+                  .arg(FreeWerte.value(i),4,'f',2));
+      }else
     p.drawText(i*w, qMax((int)(h-(RWerte.at(i)/25*h)),fh+5)-fh-2, w,fh,Qt::AlignLeft, QString("%1")
 		    .arg(RWerte.at(i),4,'f',2));
   }
@@ -410,6 +444,20 @@ bool HistoryWidget::event(QEvent *event){
     else fcfname=saveFilesList.at(index);
     fcfname.replace(fcfname.size()-3,3,"fcf");
     bool fcfda=QFile::exists(fcfname);
+    if (FreeWerte.contains(index)){
+        QToolTip::showText(helpEvent->globalPos(),
+        QString("<b>%4:</b><br> R1(Free) = <b>%9</b><br>R1 = <b>%1</b><br>R1all = <b>%2</b><br>Reflection/Parameter = <b>%3</b><br>Reflection = <b>%6</b><br>Parameter = <b>%7</b><br>FCF-File present: <b>%8</b><br>Last modified: <b>%5</b>")
+                        .arg(RWerte.at(index))
+                        .arg(RallWerte.at(index))
+                        .arg(((index<gooddata.size())&&(index<parameters.size()))  ?(double) gooddata.at(index) / parameters.at(index):0)
+                        .arg((index<saveFilesList.size())?saveFilesList.at(index):0)
+                        .arg((index<dateTimesList.size())?dateTimesList.at(index).toString("d MMM yyyy - hh:mm:ss"):"??")
+                        .arg((index<gooddata.size())?gooddata.at(index):0)
+                        .arg((index<parameters.size())?parameters.at(index):0)
+                        .arg((fcfda)?"Yes":"No")
+                        .arg(FreeWerte.value(index)));
+
+    }else
     QToolTip::showText(helpEvent->globalPos(),
     QString("<b>%4:</b><br>R1 = <b>%1</b><br>R1all = <b>%2</b><br>Reflection/Parameter = <b>%3</b><br>Reflection = <b>%6</b><br>Parameter = <b>%7</b><br>FCF-File present: <b>%8</b><br>Last modified: <b>%5</b>")
                     .arg(RWerte.at(index))
