@@ -21,6 +21,7 @@
 
 #include <QWidget>
 #include <QDateTime>
+#include <QMap>
 /*! \brief HistoryWidget is a widget which shows previous versions as bars with a height and color corresoponding to the R-value 
  *  of the previous refinement. 
  *
@@ -34,6 +35,7 @@ class HistoryWidget : public QWidget {
 public:
     explicit HistoryWidget(QWidget *parent = 0);
     QList<double> RWerte;//!< List of R1 values
+    QMap<int,double> FreeWerte;//!< List of R1Free values
     QList<double> RallWerte;//!< List of Rall values
     QList<int> gooddata;//!< Number of reflections above a sigma cutoff
     QList<int> alldata;//!< Totol number of reflections
