@@ -360,6 +360,10 @@ public:
        double  qboMin,qboMax;
   int LOD;//!< The Level of Detail
   Molecule();//!<The constructor
+  void setHBondMaxDist(double d);
+  void setHBondMaxAngl(double w);
+  double hbdist();
+  double hbangl();
   void Farbverlauf (GLfloat wrt,GLfloat min,GLfloat max);//!<computes a gradient color for wrt which is between min and max and calls glColor. @param wrt value for which a color should be assigned. @param min minimum value of wrt.  @param max maximum value of wrt.
   Cell cell;//!<The unit cell parameters
   QString Fragments;//!<A html string of the kind "<b>The asymmetric unit contains N fragments.</b><br>" were N is the number of fragments.
