@@ -162,6 +162,7 @@ public:
   void invert();//!< inverts the structure and changes ot the right enantiomorph space group.
 //  inline int Intersect( double& vm, double& vp ){ return vm*vp <= 0.0 && (vm<0.0 || vp<0.0); }//!<
   void isUpToDate(QNetworkReply* antwort);//!< Interpretes the network reply for the check for updates (manual version)
+  void jnk();//!< Julian Henn and Kathrin Meindl frcatal dimension analisis
   void jumpToAtom(int index);//!< if rename mode is visible the atom at index gets renamed if not the cursor of the editor is pointed to the specified atom.
   void jumpToError();//!< the cursor points to the first syntax error in the file.
   void loadAFile();//!< (re)loads the file specified in dirName.
@@ -434,7 +435,7 @@ private:
   QString load_sheldrick(QString fileName);
   bool maybeSave();  
   bool maybeSave2();
-  bool ediVis,oupVis;
+  bool ediVis,oupVis,startFused;
 };
 #endif
 
